Class: Google::Cloud::DataCatalog::V1beta1::DataCatalog::Rest::ServiceStub Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::V1beta1::DataCatalog::Rest::ServiceStub
- Defined in:
- lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb
Overview
This service is deprecated and may be removed in the next major version update.
REST service stub for the DataCatalog service. Service stub contains baseline method implementations including transcoding, making the REST call, and deserialing the response.
Instance Method Summary collapse
-
#create_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the create_entry REST call.
-
#create_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the create_entry_group REST call.
-
#create_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Tag
Baseline implementation for the create_tag REST call.
-
#create_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the create_tag_template REST call.
-
#create_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the create_tag_template_field REST call.
-
#delete_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_entry REST call.
-
#delete_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_entry_group REST call.
-
#delete_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag REST call.
-
#delete_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag_template REST call.
-
#delete_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag_template_field REST call.
-
#endpoint ⇒ String
The effective endpoint.
-
#get_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the get_entry REST call.
-
#get_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the get_entry_group REST call.
-
#get_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy
Baseline implementation for the get_iam_policy REST call.
-
#get_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the get_tag_template REST call.
-
#list_entries(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListEntriesResponse
Baseline implementation for the list_entries REST call.
-
#list_entry_groups(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListEntryGroupsResponse
Baseline implementation for the list_entry_groups REST call.
-
#list_tags(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListTagsResponse
Baseline implementation for the list_tags REST call.
-
#logger(stub: false) ⇒ Logger
The logger used for request/response debug logging.
-
#lookup_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the lookup_entry REST call.
-
#rename_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the rename_tag_template_field REST call.
-
#rename_tag_template_field_enum_value(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the rename_tag_template_field_enum_value REST call.
-
#search_catalog(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::SearchCatalogResponse
Baseline implementation for the search_catalog REST call.
-
#set_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy
Baseline implementation for the set_iam_policy REST call.
-
#test_iam_permissions(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::TestIamPermissionsResponse
Baseline implementation for the test_iam_permissions REST call.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the update_entry REST call.
-
#update_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the update_entry_group REST call.
-
#update_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Tag
Baseline implementation for the update_tag REST call.
-
#update_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the update_tag_template REST call.
-
#update_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the update_tag_template_field REST call.
Instance Method Details
#create_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the create_entry REST call
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 331 def create_entry request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_create_entry_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "create_entry", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Entry.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#create_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the create_entry_group REST call
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 131 def create_entry_group request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_create_entry_group_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "create_entry_group", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::EntryGroup.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#create_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Tag
Baseline implementation for the create_tag REST call
931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 931 def create_tag request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_create_tag_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "create_tag", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Tag.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#create_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the create_tag_template REST call
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 571 def create_tag_template request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_create_tag_template_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "create_tag_template", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplate.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#create_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the create_tag_template_field REST call
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 731 def create_tag_template_field request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_create_tag_template_field_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "create_tag_template_field", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#delete_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_entry REST call
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 411 def delete_entry request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_delete_entry_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "delete_entry", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#delete_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_entry_group REST call
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 251 def delete_entry_group request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_delete_entry_group_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "delete_entry_group", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#delete_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag REST call
1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 1011 def delete_tag request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_delete_tag_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "delete_tag", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#delete_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag_template REST call
691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 691 def delete_tag_template request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_delete_tag_template_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "delete_tag_template", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#delete_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Baseline implementation for the delete_tag_template_field REST call
891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 891 def delete_tag_template_field request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_delete_tag_template_field_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "delete_tag_template_field", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#endpoint ⇒ String
The effective endpoint
64 65 66 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 64 def endpoint @client_stub.endpoint end |
#get_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the get_entry REST call
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 451 def get_entry request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_get_entry_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "get_entry", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Entry.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#get_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the get_entry_group REST call
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 211 def get_entry_group request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_get_entry_group_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "get_entry_group", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::EntryGroup.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#get_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy
Baseline implementation for the get_iam_policy REST call
1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 1131 def get_iam_policy request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_get_iam_policy_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "get_iam_policy", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Iam::V1::Policy.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#get_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the get_tag_template REST call
611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 611 def get_tag_template request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_get_tag_template_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "get_tag_template", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplate.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#list_entries(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListEntriesResponse
Baseline implementation for the list_entries REST call
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 531 def list_entries request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_list_entries_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "list_entries", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::ListEntriesResponse.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#list_entry_groups(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListEntryGroupsResponse
Baseline implementation for the list_entry_groups REST call
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 291 def list_entry_groups request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_list_entry_groups_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "list_entry_groups", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::ListEntryGroupsResponse.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#list_tags(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::ListTagsResponse
Baseline implementation for the list_tags REST call
1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 1051 def request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub. request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "list_tags", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::ListTagsResponse.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#logger(stub: false) ⇒ Logger
The logger used for request/response debug logging.
73 74 75 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 73 def logger stub: false stub ? @client_stub.stub_logger : @client_stub.logger end |
#lookup_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the lookup_entry REST call
491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 491 def lookup_entry request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_lookup_entry_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "lookup_entry", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Entry.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#rename_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the rename_tag_template_field REST call
811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 811 def rename_tag_template_field request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_rename_tag_template_field_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "rename_tag_template_field", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#rename_tag_template_field_enum_value(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the rename_tag_template_field_enum_value REST call
851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 851 def rename_tag_template_field_enum_value request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_rename_tag_template_field_enum_value_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "rename_tag_template_field_enum_value", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#search_catalog(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::SearchCatalogResponse
Baseline implementation for the search_catalog REST call
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 91 def search_catalog request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_search_catalog_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "search_catalog", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::SearchCatalogResponse.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#set_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy
Baseline implementation for the set_iam_policy REST call
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 1091 def set_iam_policy request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_set_iam_policy_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "set_iam_policy", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Iam::V1::Policy.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#test_iam_permissions(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::TestIamPermissionsResponse
Baseline implementation for the test_iam_permissions REST call
1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 1171 def request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub. request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "test_iam_permissions", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Iam::V1::TestIamPermissionsResponse.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#universe_domain ⇒ String
The effective universe domain
55 56 57 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 55 def universe_domain @client_stub.universe_domain end |
#update_entry(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Entry
Baseline implementation for the update_entry REST call
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 371 def update_entry request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_update_entry_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "update_entry", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Entry.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#update_entry_group(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::EntryGroup
Baseline implementation for the update_entry_group REST call
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 171 def update_entry_group request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_update_entry_group_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "update_entry_group", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::EntryGroup.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#update_tag(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::Tag
Baseline implementation for the update_tag REST call
971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 971 def update_tag request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_update_tag_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "update_tag", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::Tag.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#update_tag_template(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplate
Baseline implementation for the update_tag_template REST call
651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 651 def update_tag_template request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_update_tag_template_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "update_tag_template", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplate.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |
#update_tag_template_field(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField
Baseline implementation for the update_tag_template_field REST call
771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 |
# File 'lib/google/cloud/data_catalog/v1beta1/data_catalog/rest/service_stub.rb', line 771 def update_tag_template_field request_pb, = nil raise ::ArgumentError, "request must be provided" if request_pb.nil? verb, uri, query_string_params, body = ServiceStub.transcode_update_tag_template_field_request request_pb query_string_params = if query_string_params.any? query_string_params.to_h { |p| p.split "=", 2 } else {} end response = @client_stub.make_http_request( verb, uri: uri, body: body || "", params: query_string_params, method_name: "update_tag_template_field", options: ) operation = ::Gapic::Rest::TransportOperation.new response result = ::Google::Cloud::DataCatalog::V1beta1::TagTemplateField.decode_json response.body, ignore_unknown_fields: true catch :response do yield result, operation if block_given? result end end |